@@ -6,6 +6,10 @@ BASE_URL = "https://api.up.com.au/api/v1"
 TRANSACTION_HELD = "HELD"
 TRANSACTION_SETTLED = "SETTLED"
 
+DEFAULT_PAGE_SIZE = 20
+DEFAULT_LIMIT = 20
+
+
 # WEBHOOK_EVENT_TRANSACTION_CREATED = "TRANSACTION_CREATED"
 # WEBHOOK_EVENT_TRANSACTION_SETTLED = "TRANSACTION_SETTLED"
 # WEBHOOK_EVENT_TRANSACTION_DELETED = "TRANSACTION_DELETED"
